@@ -4,7 +4,6 @@ use warnings FATAL => 'all';
 use 5.008005;
 use base 'Module::Build::XSUtil';
 use Config;
-use Devel::CheckBin qw(check_bin);
 use File::Spec;
 use File::Which qw(which);
 use File::chdir;
@@ -20,12 +19,6 @@ sub _build_dependencies {
     # Skip if already built
     return if -e "$abs/build";
 
-    # libevent
-    check_bin('autoconf');
-    check_bin('automake');
-    check_bin('libtoolize');
-    check_bin('pkg-config');
-
     my $make;
     if ($^O =~ m/(bsd|dragonfly)$/ && $^O !~ m/gnukfreebsd$/) {
         my $gmake = which('gmake');
@@ -41,22 +34,6 @@ sub _build_dependencies {
         $self->do_system('git', 'submodule', 'update', '--init');
     }
 
-    # libevent
-    {
-        local $CWD = "deps/libevent";
-        $self->do_system('./autogen.sh');
-        $self->do_system('./configure',
-            '--disable-openssl',
-            '--disable-samples',
-            '--disable-shared',
-            '--with-pic',
-            '--prefix',
-            "$abs/build/usr/local",
-        );
-        $self->do_system($make);
-        $self->do_system($make, 'install');
-    }
-
     # hiredis
     $self->do_system($make, '-C', 'deps/hiredis', "USE_SSL=0", "DESTDIR=$abs/build", 'all', 'install');
 
@@ -83,7 +60,7 @@ sub new {
             'deps/build/usr/local/include',
         ],
         extra_linker_flags => [
-            "deps/build/usr/local/lib/libevent$Config{lib_ext}",
+            "-levent",
             "deps/build/usr/local/lib/libhiredis$Config{lib_ext}",
             "deps/build/usr/local/lib/libhiredis_cluster$Config{lib_ext}",
         ],
